@@ -47,7 +47,7 @@ pub fn get_args(tagged_filterer: bool) -> Result<ArgMatches<'static>> {
 			.multiple(true)
 			.takes_value(true))
 		.arg(Arg::with_name("clear")
-			.help_heading(Some(OPTSET_BEHAVIOUR))
+			.help_heading(Some(OPTSET_OUTPUT))
 			.help("Clear screen before executing command")
 			.short("c")
 			.long("clear"))
@@ -76,7 +76,7 @@ pub fn get_args(tagged_filterer: bool) -> Result<ArgMatches<'static>> {
 			.long("kill"))
 		.arg(Arg::with_name("debounce")
 			.help_heading(Some(OPTSET_BEHAVIOUR))
-			.help("Set the timeout between detected change and command execution, defaults to 100ms")
+			.help("Set the timeout between detected change and command execution, defaults to 50ms")
 			.takes_value(true)
 			.value_name("milliseconds")
 			.short("d")
@@ -124,7 +124,7 @@ pub fn get_args(tagged_filterer: bool) -> Result<ArgMatches<'static>> {
 			.help(if cfg!(windows) {
 				"Use a different shell, or `none`. Try --shell=powershell, which will become the default in 2.0."
 			} else {
-			"Use a different shell, or `none`. E.g. --shell=bash"
+			"Use a different shell, or `none`. Defaults to `sh` (until 2.0, where that will change to `$SHELL`). E.g. --shell=bash"
 			})
 			.takes_value(true)
 			.long("shell"))
@@ -135,7 +135,7 @@ pub fn get_args(tagged_filterer: bool) -> Result<ArgMatches<'static>> {
 			.short("n")
 			.long("no-shell"))
 		.arg(Arg::with_name("no-environment")
-			.help_heading(Some(OPTSET_OUTPUT))
+			.help_heading(Some(OPTSET_COMMAND))
 			.help("Do not set WATCHEXEC_*_PATH environment variables for the command")
 			.long("no-environment"))
 		.arg(Arg::with_name("no-process-group")
@@ -153,7 +153,25 @@ pub fn get_args(tagged_filterer: bool) -> Result<ArgMatches<'static>> {
 			.help_heading(Some(OPTSET_OUTPUT))
 			.help("Send a desktop notification when the command ends")
 			.short("N")
-			.long("notify"));
+			.long("notify"))
+		.arg(Arg::with_name("project-origin")
+			.help_heading(Some(OPTSET_FILTERING))
+			.help("Override the project origin: the directory from which ignore files are detected")
+			.value_name("path")
+			.long("project-origin"))
+		.arg(Arg::with_name("command-workdir")
+			.help_heading(Some(OPTSET_COMMAND))
+			.help("Change the working directory of the command")
+			.value_name("path")
+			.long("workdir"))
+		.arg(Arg::with_name("command-env")
+			.help_heading(Some(OPTSET_COMMAND))
+			.help("Add an environment variable to the command")
+			.value_name("name=value")
+			.long("env")
+			.short("E")
+			.number_of_values(1)
+			.multiple(true));
 
 	let app = if tagged_filterer {
 		app.arg(
